summaryrefslogtreecommitdiff
path: root/src/mongo/s/commands/cluster_is_master_cmd.cpp
diff options
context:
space:
mode:
authorPavi Vetriselvan <pavithra.vetriselvan@mongodb.com>2020-09-22 12:09:56 -0400
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-09-29 17:17:35 +0000
commit861970ebd4f54a5feb23f82e2db3e9e00b0b32c1 (patch)
tree3194baabd60c5eaa855810cdeb653572939dea6f /src/mongo/s/commands/cluster_is_master_cmd.cpp
parent5ecee573374e0131e3c3454392b2c51694a7f175 (diff)
downloadmongo-861970ebd4f54a5feb23f82e2db3e9e00b0b32c1.tar.gz
SERVER-50415 rename waitInIsMaster failpoint to waitInHello
Diffstat (limited to 'src/mongo/s/commands/cluster_is_master_cmd.cpp')
-rw-r--r--src/mongo/s/commands/cluster_is_master_cmd.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/s/commands/cluster_is_master_cmd.cpp b/src/mongo/s/commands/cluster_is_master_cmd.cpp
index ced249eb614..08917ebc0e5 100644
--- a/src/mongo/s/commands/cluster_is_master_cmd.cpp
+++ b/src/mongo/s/commands/cluster_is_master_cmd.cpp
@@ -51,8 +51,8 @@
namespace mongo {
-// Hangs in the beginning of each isMaster command when set.
-MONGO_FAIL_POINT_DEFINE(waitInIsMaster);
+// Hangs in the beginning of each hello command when set.
+MONGO_FAIL_POINT_DEFINE(waitInHello);
namespace {
@@ -97,7 +97,7 @@ public:
rpc::ReplyBuilderInterface* replyBuilder) final {
CommandHelpers::handleMarkKillOnClientDisconnect(opCtx);
- waitInIsMaster.pauseWhileSet(opCtx);
+ waitInHello.pauseWhileSet(opCtx);
auto& clientMetadataIsMasterState = ClientMetadataIsMasterState::get(opCtx->getClient());
bool seenIsMaster = clientMetadataIsMasterState.hasSeenIsMaster();